estfun.ssym <-
function(object, ...){
list(mu=object$score.mu, phi=object$score.phi)}
